#
# spec file for package python-javaproperties
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-javaproperties
Version:        0.8.1
Release:        2.4
Summary:        Read & Write Java Properties Files
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jwodder/javaproperties
Source:         https://files.pythonhosted.org/packages/source/j/javaproperties/javaproperties-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-mock >= 2.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Read & write Java .properties files.

%prep
%autosetup -p1 -n javaproperties-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
sed -i -e '/--cov/d' -e '/--no-cov/d' -e '/--flakes/d' -e '/--doctest-modules/d' tox.ini
export LC_ALL='en_US.UTF-8'
export TZ=EST5EDT,M3.2.0,M11.1.0
%pytest test

%files %{python_files}
%doc CHANGELOG.md README.rst
%license LICENSE
%{python_sitelib}/javaproperties*

%changelog
* Wed Mar  6 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Add %%{?sle15_python_module_pythons}
* Mon Apr  3 2023 pgajdos@suse.com
- version update to 0.8.1
  v0.8.1 (2021-10-05)
  - ------------------
  - Fix a typing issue in Python 3.9
  - Support Python 3.10
  v0.8.0 (2020-11-28)
  - ------------------
  - Drop support for Python 2.7, 3.4, and 3.5
  - Support Python 3.9
  - `ensure_ascii` parameter added to `PropertiesFile.dump()` and
    `PropertiesFile.dumps()`
  - **Bugfix**: When parsing XML input, empty `<entry>` tags now produce an empty
    string as a value, not `None`
  - Added type annotations
  - `Properties` and `PropertiesFile` no longer raise `TypeError` when given a
    non-string key or value, as type correctness is now expected to be enforced
    through static type checking
  - The `PropertiesElement` classes returned by `parse()` are no longer
    subclasses of `namedtuple`, but they can still be iterated over to retrieve
    their fields like a tuple
- python-six is not required
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 0.7.0
  v0.7.0 (2020-03-09)
  - ------------------
  - `parse()` now accepts strings as input
  - **Breaking**: `parse()` now returns a generator of custom objects instead of
    triples of strings
  - Gave `PropertiesFile` a settable `timestamp` property
  - Gave `PropertiesFile` a settable `header_comment` property
  - Handle unescaping surrogate pairs on narrow Python builds
  v0.6.0 (2020-02-28)
  - ------------------
  - Include changelog in the Read the Docs site
  - Support Python 3.8
  - When dumping a value that begins with more than one space, only escape the
    first space in order to better match Java's behavior
  - Gave `dump()`, `dumps()`, `escape()`, and `join_key_value()` an
    `ensure_ascii` parameter for optionally not escaping non-ASCII characters in
    output
  - Gave `dump()` and `dumps()` an `ensure_ascii_comments` parameter for
    controlling what characters in the `comments` parameter are escaped
  - Gave `to_comment()` an `ensure_ascii` parameter for controlling what
    characters are escaped
  - Added a custom encoding error handler `'javapropertiesreplace'` that encodes
    invalid characters as `\uXXXX` escape sequences
- really test the package
* Tue Nov 26 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.5.2
